@@ -5,7 +5,7 @@ import os
 import yaml
 from prospector.tools import TOOLS
 
-BUILTIN_PROFILE_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), 'profiles'))
+BUILTIN_PROFILE_PATH = os.path.abspath(os.path.join(os.path.dirname(__file__), "profiles"))
 
 
 class ProfileNotFound(Exception):
@@ -15,7 +15,10 @@ class ProfileNotFound(Exception):
         self.profile_path = profile_path
 
     def __repr__(self):
-        return "Could not find profile %s; searched in %s" % (self.name, ':'.join(self.profile_path))
+        return "Could not find profile %s; searched in %s" % (
+            self.name,
+            ":".join(self.profile_path),
+        )
 
 
 class CannotParseProfile(Exception):
@@ -25,64 +28,59 @@ class CannotParseProfile(Exception):
         self.parse_error = parse_error
 
     def get_parse_message(self):
-        return '%s\n  on line %s : char %s' % (self.parse_error.problem,
-                                               self.parse_error.problem_mark.line,
-                                               self.parse_error.problem_mark.column)
+        return "%s\n  on line %s : char %s" % (
+            self.parse_error.problem,
+            self.parse_error.problem_mark.line,
+            self.parse_error.problem_mark.column,
+        )
 
     def __repr__(self):
         return "Could not parse profile found at %s - it is not valid YAML" % self.filepath
 
 
 class ProspectorProfile(object):
-
     def __init__(self, name, profile_dict, inherit_order):
         self.name = name
         self.inherit_order = inherit_order
 
-        self.ignore_paths = _ensure_list(profile_dict.get('ignore-paths', []))
+        self.ignore_paths = _ensure_list(profile_dict.get("ignore-paths", []))
         # The 'ignore' directive is an old one which should be deprecated at some point
-        self.ignore_patterns = _ensure_list(
-            profile_dict.get('ignore-patterns', []) + profile_dict.get('ignore', [])
-        )
+        self.ignore_patterns = _ensure_list(profile_dict.get("ignore-patterns", []) + profile_dict.get("ignore", []))
 
-        self.output_format = profile_dict.get('output-format')
-        self.output_target = profile_dict.get('output-target')
-        self.autodetect = profile_dict.get('autodetect')
-        self.uses = [uses for uses in _ensure_list(profile_dict.get('uses', []))
-                     if uses in ('django', 'celery', 'flask')]
-        self.max_line_length = profile_dict.get('max-line-length')
+        self.output_format = profile_dict.get("output-format")
+        self.output_target = profile_dict.get("output-target")
+        self.autodetect = profile_dict.get("autodetect")
+        self.uses = [
+            uses for uses in _ensure_list(profile_dict.get("uses", [])) if uses in ("django", "celery", "flask")
+        ]
+        self.max_line_length = profile_dict.get("max-line-length")
 
         # informational shorthands
-        self.strictness = profile_dict.get('strictness')
-        self.test_warnings = profile_dict.get('test-warnings')
-        self.doc_warnings = profile_dict.get('doc-warnings')
-        self.member_warnings = profile_dict.get('member-warnings')
+        self.strictness = profile_dict.get("strictness")
+        self.test_warnings = profile_dict.get("test-warnings")
+        self.doc_warnings = profile_dict.get("doc-warnings")
+        self.member_warnings = profile_dict.get("member-warnings")
 
         # TODO: this is needed by Landscape but not by prospector; there is probably a better place for it
-        self.requirements = _ensure_list(profile_dict.get('requirements', []))
-        self.python_targets = _ensure_list(profile_dict.get('python-targets', []))
+        self.requirements = _ensure_list(profile_dict.get("requirements", []))
+        self.python_targets = _ensure_list(profile_dict.get("python-targets", []))
 
         for tool in TOOLS.keys():
-            conf = {
-                'disable': [],
-                'enable': [],
-                'run': None,
-                'options': {}
-            }
+            conf = {"disable": [], "enable": [], "run": None, "options": {}}
             conf.update(profile_dict.get(tool, {}))
 
-            if self.max_line_length is not None and tool in ('pylint', 'pep8'):
-                conf['options']['max-line-length'] = self.max_line_length
+            if self.max_line_length is not None and tool in ("pylint", "pep8"):
+                conf["options"]["max-line-length"] = self.max_line_length
 
             setattr(self, tool, conf)
 
     def get_disabled_messages(self, tool_name):
-        disable = getattr(self, tool_name)['disable']
-        enable = getattr(self, tool_name)['enable']
+        disable = getattr(self, tool_name)["disable"]
+        enable = getattr(self, tool_name)["enable"]
         return list(set(disable) - set(enable))
 
     def is_tool_enabled(self, name):
-        return getattr(self, name).get('run')
+        return getattr(self, name).get("run")
 
     def list_profiles(self):
         # this profile is itself included
@@ -90,19 +88,19 @@ class ProspectorProfile(object):
 
     def as_dict(self):
         out = {
-            'ignore-paths': self.ignore_paths,
-            'ignore-patterns': self.ignore_patterns,
-            'output-format': self.output_format,
-            'output-target': self.output_target,
-            'autodetect': self.autodetect,
-            'uses': self.uses,
-            'max-line-length': self.max_line_length,
-            'member-warnings': self.member_warnings,
-            'doc-warnings': self.doc_warnings,
-            'test-warnings': self.test_warnings,
-            'strictness': self.strictness,
-            'requirements': self.requirements,
-            'python-targets': self.python_targets,
+            "ignore-paths": self.ignore_paths,
+            "ignore-patterns": self.ignore_patterns,
+            "output-format": self.output_format,
+            "output-target": self.output_target,
+            "autodetect": self.autodetect,
+            "uses": self.uses,
+            "max-line-length": self.max_line_length,
+            "member-warnings": self.member_warnings,
+            "doc-warnings": self.doc_warnings,
+            "test-warnings": self.test_warnings,
+            "strictness": self.strictness,
+            "requirements": self.requirements,
+            "python-targets": self.python_targets,
         }
         for tool in TOOLS.keys():
             out[tool] = getattr(self, tool)
@@ -117,14 +115,18 @@ class ProspectorProfile(object):
     @staticmethod
     def load(name_or_path, profile_path, allow_shorthand=True, forced_inherits=None):
         # First simply load all of the profiles and those that it explicitly inherits from
-        data, inherits = _load_and_merge(name_or_path, profile_path, allow_shorthand,
-                                         forced_inherits=forced_inherits or [])
+        data, inherits = _load_and_merge(
+            name_or_path,
+            profile_path,
+            allow_shorthand,
+            forced_inherits=forced_inherits or [],
+        )
         return ProspectorProfile(name_or_path, data, inherits)
 
 
 def _is_valid_extension(filename):
     ext = os.path.splitext(filename)[1]
-    return ext in ('.yml', '.yaml')
+    return ext in (".yml", ".yaml")
 
 
 def _load_content(name_or_path, profile_path):
@@ -142,8 +144,8 @@ def _load_content(name_or_path, profile_path):
             raise ProfileNotFound(name_or_path, profile_path)
     else:
         for path in profile_path:
-            for ext in ('yml', 'yaml'):
-                filepath = os.path.join(path, '%s.%s' % (name_or_path, ext))
+            for ext in ("yml", "yaml"):
+                filepath = os.path.join(path, "%s.%s" % (name_or_path, ext))
                 if os.path.exists(filepath):
                     filename = filepath
                     break
@@ -175,20 +177,20 @@ def _merge_tool_config(priority, base):
     for key, value in priority.items():
         # pep8 has extra 'full' and 'none' options
         # pylint has extra 'load-plugins' option
-        if key in ('run', 'full', 'none', 'load-plugins'):
+        if key in ("run", "full", "none", "load-plugins"):
             out[key] = value
-        elif key in ('options',):
+        elif key in ("options",):
             out[key] = _simple_merge_dict(value, base.get(key, {}))
 
     # anything enabled in the 'priority' dict is removed
     # from 'disabled' in the base dict and vice versa
-    base_disabled = base.get('disable') or []
-    base_enabled = base.get('enable') or []
-    pri_disabled = priority.get('disable') or []
-    pri_enabled = priority.get('enable') or []
+    base_disabled = base.get("disable") or []
+    base_enabled = base.get("enable") or []
+    pri_disabled = priority.get("disable") or []
+    pri_enabled = priority.get("enable") or []
 
-    out['disable'] = list(set(pri_disabled) | (set(base_disabled) - set(pri_enabled)))
-    out['enable'] = list(set(pri_enabled) | (set(base_enabled) - set(pri_disabled)))
+    out["disable"] = list(set(pri_disabled) | (set(base_disabled) - set(pri_enabled)))
+    out["enable"] = list(set(pri_enabled) | (set(base_enabled) - set(pri_disabled)))
 
     return out
 
@@ -198,12 +200,26 @@ def _merge_profile_dict(priority, base):
     out = dict(base.items())
 
     for key, value in priority.items():
-        if key in ('strictness', 'doc-warnings', 'test-warnings', 'member-warnings',
-                   'output-format', 'autodetect', 'max-line-length',):
+        if key in (
+            "strictness",
+            "doc-warnings",
+            "test-warnings",
+            "member-warnings",
+            "output-format",
+            "autodetect",
+            "max-line-length",
+        ):
             # some keys are simple values which are overwritten
             out[key] = value
-        elif key in ('ignore', 'ignore-patterns', 'ignore-paths', 'uses',
-                     'requirements', 'python-targets'):
+        elif key in (
+            "ignore",
+            "ignore-patterns",
+            "ignore-paths",
+            "uses",
+            "requirements",
+            "python-targets",
+            "output-target",
+        ):
             # some keys should be appended
             out[key] = _ensure_list(value) + _ensure_list(base.get(key, []))
         elif key in TOOLS.keys():
@@ -215,43 +231,43 @@ def _merge_profile_dict(priority, base):
 
 def _determine_strictness(profile_dict, inherits):
     for profile in inherits:
-        if profile.startswith('strictness_'):
+        if profile.startswith("strictness_"):
             return None, False
 
-    strictness = profile_dict.get('strictness')
+    strictness = profile_dict.get("strictness")
     if strictness is None:
         return None, False
-    return ('strictness_%s' % strictness), True
+    return ("strictness_%s" % strictness), True
 
 
 def _determine_pep8(profile_dict):
-    pep8 = profile_dict.get('pep8', {})
-    if pep8.get('full', False):
-        return 'full_pep8', True
-    elif pep8.get('none', False):
-        return 'no_pep8', True
+    pep8 = profile_dict.get("pep8", {})
+    if pep8.get("full", False):
+        return "full_pep8", True
+    elif pep8.get("none", False):
+        return "no_pep8", True
     return None, False
 
 
 def _determine_doc_warnings(profile_dict):
-    doc_warnings = profile_dict.get('doc-warnings')
+    doc_warnings = profile_dict.get("doc-warnings")
     if doc_warnings is None:
         return None, False
-    return ('doc_warnings' if doc_warnings else 'no_doc_warnings'), True
+    return ("doc_warnings" if doc_warnings else "no_doc_warnings"), True
 
 
 def _determine_test_warnings(profile_dict):
-    test_warnings = profile_dict.get('test-warnings')
+    test_warnings = profile_dict.get("test-warnings")
     if test_warnings is None:
         return None, False
-    return (None if test_warnings else 'no_test_warnings'), True
+    return (None if test_warnings else "no_test_warnings"), True
 
 
 def _determine_member_warnings(profile_dict):
-    member_warnings = profile_dict.get('member-warnings')
+    member_warnings = profile_dict.get("member-warnings")
     if member_warnings is None:
         return None, False
-    return ('member_warnings' if member_warnings else 'no_member_warnings'), True
+    return ("member_warnings" if member_warnings else "no_member_warnings"), True
 
 
 def _determine_implicit_inherits(profile_dict, already_inherits, shorthands_found):
@@ -260,11 +276,11 @@ def _determine_implicit_inherits(profile_dict, already_inherits, shorthands_foun
     # the doc/test/pep8 profiles is usually to restore items which were
     # turned off in the strictness profile, so they must appear first.
     implicit = [
-        ('pep8', _determine_pep8(profile_dict)),
-        ('docs', _determine_doc_warnings(profile_dict)),
-        ('tests', _determine_test_warnings(profile_dict)),
-        ('strictness', _determine_strictness(profile_dict, already_inherits)),
-        ('members', _determine_member_warnings(profile_dict)),
+        ("pep8", _determine_pep8(profile_dict)),
+        ("docs", _determine_doc_warnings(profile_dict)),
+        ("tests", _determine_test_warnings(profile_dict)),
+        ("strictness", _determine_strictness(profile_dict, already_inherits)),
+        ("members", _determine_member_warnings(profile_dict)),
     ]
     inherits = []
 
@@ -290,27 +306,30 @@ def _append_profiles(name, profile_path, data, inherit_list, allow_shorthand=Fal
 
 def _load_and_merge(name_or_path, profile_path, allow_shorthand=True, forced_inherits=None):
     # First simply load all of the profiles and those that it explicitly inherits from
-    data, inherit_list, shorthands_found = _load_profile(name_or_path, profile_path,
-                                                         allow_shorthand=allow_shorthand,
-                                                         forced_inherits=forced_inherits or [])
+    data, inherit_list, shorthands_found = _load_profile(
+        name_or_path,
+        profile_path,
+        allow_shorthand=allow_shorthand,
+        forced_inherits=forced_inherits or [],
+    )
 
     if allow_shorthand:
-        if 'docs' not in shorthands_found:
-            data, inherit_list = _append_profiles('no_doc_warnings', profile_path, data, inherit_list)
+        if "docs" not in shorthands_found:
+            data, inherit_list = _append_profiles("no_doc_warnings", profile_path, data, inherit_list)
 
-        if 'members' not in shorthands_found:
-            data, inherit_list = _append_profiles('no_member_warnings', profile_path, data, inherit_list)
+        if "members" not in shorthands_found:
+            data, inherit_list = _append_profiles("no_member_warnings", profile_path, data, inherit_list)
 
-        if 'tests' not in shorthands_found:
-            data, inherit_list = _append_profiles('no_test_warnings', profile_path, data, inherit_list)
+        if "tests" not in shorthands_found:
+            data, inherit_list = _append_profiles("no_test_warnings", profile_path, data, inherit_list)
 
-        if 'strictness' not in shorthands_found:
+        if "strictness" not in shorthands_found:
             # if no strictness was specified, then we should manually insert the medium strictness
             for inherit in inherit_list:
-                if inherit.startswith('strictness_'):
+                if inherit.startswith("strictness_"):
                     break
             else:
-                data, inherit_list = _append_profiles('strictness_medium', profile_path, data, inherit_list)
+                data, inherit_list = _append_profiles("strictness_medium", profile_path, data, inherit_list)
 
     # Now we merge all of the values together, from 'right to left' (ie, from the
     # top of the inheritance tree to the bottom). This means that the lower down
@@ -324,8 +343,14 @@ def _load_and_merge(name_or_path, profile_path, allow_shorthand=True, forced_inh
     return merged, inherit_list
 
 
-def _load_profile(name_or_path, profile_path, shorthands_found=None,
-                  already_loaded=None, allow_shorthand=True, forced_inherits=None):
+def _load_profile(
+    name_or_path,
+    profile_path,
+    shorthands_found=None,
+    already_loaded=None,
+    allow_shorthand=True,
+    forced_inherits=None,
+):
     # recursively get the contents of the basic profile and those it inherits from
     base_contents = _load_content(name_or_path, profile_path)
 
@@ -335,13 +360,13 @@ def _load_profile(name_or_path, profile_path, shorthands_found=None,
     already_loaded = already_loaded or []
     already_loaded.append(name_or_path)
 
-    inherits = _ensure_list(base_contents.get('inherits', []))
+    inherits = _ensure_list(base_contents.get("inherits", []))
     if forced_inherits is not None:
         inherits += forced_inherits
 
     # There are some 'shorthand' options in profiles which implicitly mean that we
     # should inherit from some of prospector's built-in profiles
-    if base_contents.get('allow-shorthand', True) and allow_shorthand:
+    if base_contents.get("allow-shorthand", True) and allow_shorthand:
         extra_inherits, extra_shorthands = _determine_implicit_inherits(base_contents, inherits, shorthands_found)
         inherits += extra_inherits
         shorthands_found |= extra_shorthands
@@ -354,8 +379,13 @@ def _load_profile(name_or_path, profile_path, shorthands_found=None,
             continue
 
         already_loaded.append(inherit_profile)
-        new_cd, new_il, new_sh = _load_profile(inherit_profile, profile_path,
-                                               shorthands_found, already_loaded, allow_shorthand)
+        new_cd, new_il, new_sh = _load_profile(
+            inherit_profile,
+            profile_path,
+            shorthands_found,
+            already_loaded,
+            allow_shorthand,
+        )
         contents_dict.update(new_cd)
         inherit_order += new_il
         shorthands_found |= new_sh
