@@ -1,16 +1,11 @@
+# -*- coding: utf-8 -*-
 from __future__ import absolute_import
 
-import os.path
-
-from frosted.api import iter_source_code, check_path
-
+from frosted.api import check_path
 from prospector.message import Location, Message
 from prospector.tools.base import ToolBase
 
-
-__all__ = (
-    'FrostedTool',
-)
+__all__ = ("FrostedTool",)
 
 
 class ProspectorReporter(object):
@@ -18,14 +13,8 @@ class ProspectorReporter(object):
         self._messages = []
         self.ignore = ignore or ()
 
-    # pylint: disable=R0913
-    def record_message(
-            self,
-            filename=None,
-            line=None,
-            character=None,
-            code=None,
-            message=None):
+    # pylint: disable=too-many-arguments
+    def record_message(self, filename=None, line=None, character=None, code=None, message=None):
 
         if code in self.ignore:
             return
@@ -38,7 +27,7 @@ class ProspectorReporter(object):
             character=character,
         )
         message = Message(
-            source='frosted',
+            source="frosted",
             code=code,
             location=location,
             message=message,
@@ -48,12 +37,12 @@ class ProspectorReporter(object):
     def unexpected_error(self, filename, msg):
         self.record_message(
             filename=filename,
-            code='U999',
+            code="U999",
             message=msg,
         )
 
     def flake(self, message):
-        filename, _, msg = message.message.split(':', 2)
+        filename, _, msg = message.message.split(":", 2)
 
         self.record_message(
             filename=filename,
@@ -71,19 +60,14 @@ class FrostedTool(ToolBase):
     def __init__(self, *args, **kwargs):
         super(FrostedTool, self).__init__(*args, **kwargs)
         self.ignore_codes = ()
-        self._paths = []
-        self._ignores = []
 
-    def prepare(self, found_files, args, adaptors):
-        self._files = found_files
+    def configure(self, prospector_config, _):
+        self.ignore_codes = prospector_config.get_disabled_messages("frosted")
 
-        for adaptor in adaptors:
-            adaptor.adapt_frosted(self)
-
-    def run(self):
+    def run(self, found_files):
         reporter = ProspectorReporter(ignore=self.ignore_codes)
 
-        for filepath in self._files.iter_module_paths():
+        for filepath in found_files.iter_module_paths():
             # Frosted cannot handle non-utf-8 encoded files at the moment -
             # see https://github.com/timothycrosley/frosted/issues/53
             # Therefore (since pyflakes overlaps heavily and does not have the same
@@ -94,6 +78,7 @@ class FrostedTool(ToolBase):
             try:
                 check_path(filepath, reporter)
             except UnicodeDecodeError:
+                # pylint:disable=pointless-except
                 pass
 
         return reporter.get_messages()
